@@ -68,6 +68,10 @@ class MyTreeModel(gtk.GenericTreeModel):
                         self.add_edge(node_id + '[' + extra + ']', child_id)
                 else:
                     self.add_edge(node_id, child_id)
+        for children in self.children.values():
+            for child_id in children:
+                if child_id not in self.children:
+                    self.add_node(child_id, '{%s}' % child_id, False)
 
     def add_node(self, node_id, node_name, available):
         assert node_id not in self.children
